==> huaweicloudsdkkms-3.0.45-py2.py3-none-any.whl: huaweicloudsdkkms/v1/model/update_secret_request_body.py <==
# coding: utf-8

import pprint
import re

import six





class UpdateSecretRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'kms_key_id': 'str',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'kms_key_id': 'kms_key_id',
        'description': 'description'
    }

    def __init__(self, name=None, kms_key_id=None, description=None):
        """UpdateSecretRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._kms_key_id = None
        self._description = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if kms_key_id is not None:
            self.kms_key_id = kms_key_id
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this UpdateSecretRequestBody.

        凭据名称。  约束：取值范围为1到64个字符，满足正则匹配“^[a-zA-Z0-9._-]{1,64}$”。 

        :return: The name of this UpdateSecretRequestBody.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSecretRequestBody.

        凭据名称。  约束：取值范围为1到64个字符，满足正则匹配“^[a-zA-Z0-9._-]{1,64}$”。 

        :param name: The name of this UpdateSecretRequestBody.
        :type: str
        """
        self._name = name

    @property
    def kms_key_id(self):
        """Gets the kms_key_id of this UpdateSecretRequestBody.

        用于加密保护凭据值的KMS主密钥ID。更新凭据的主密钥后，仅新创建的凭据版本使用更新后的主密钥ID加密，之前的凭据版本依旧使用之前的主密钥ID解密。 

        :return: The kms_key_id of this UpdateSecretRequestBody.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """Sets the kms_key_id of this UpdateSecretRequestBody.

        用于加密保护凭据值的KMS主密钥ID。更新凭据的主密钥后，仅新创建的凭据版本使用更新后的主密钥ID加密，之前的凭据版本依旧使用之前的主密钥ID解密。 

        :param kms_key_id: The kms_key_id of this UpdateSecretRequestBody.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def description(self):
        """Gets the description of this UpdateSecretRequestBody.

        凭据的描述信息。  约束：2048字节。 

        :return: The description of this UpdateSecretRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateSecretRequestBody.

        凭据的描述信息。  约束：2048字节。 

        :param description: The description of this UpdateSecretRequestBody.
        :type: str
        """
        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSecretRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkms-3.0.52-py2.py3-none-any.whl: huaweicloudsdkkms/v1/model/update_secret_request_body.py <==
# coding: utf-8

import re
import six





class UpdateSecretRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'kms_key_id': 'str',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'kms_key_id': 'kms_key_id',
        'description': 'description'
    }

    def __init__(self, name=None, kms_key_id=None, description=None):
        """UpdateSecretRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._name = None
        self._kms_key_id = None
        self._description = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if kms_key_id is not None:
            self.kms_key_id = kms_key_id
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this UpdateSecretRequestBody.

        凭据名称。  约束：取值范围为1到64个字符，满足正则匹配“^[a-zA-Z0-9._-]{1,64}$”。 

        :return: The name of this UpdateSecretRequestBody.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSecretRequestBody.

        凭据名称。  约束：取值范围为1到64个字符，满足正则匹配“^[a-zA-Z0-9._-]{1,64}$”。 

        :param name: The name of this UpdateSecretRequestBody.
        :type: str
        """
        self._name = name

    @property
    def kms_key_id(self):
        """Gets the kms_key_id of this UpdateSecretRequestBody.

        用于加密保护凭据值的KMS主密钥ID。更新凭据的主密钥后，仅新创建的凭据版本使用更新后的主密钥ID加密，之前的凭据版本依旧使用之前的主密钥ID解密。 

        :return: The kms_key_id of this UpdateSecretRequestBody.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """Sets the kms_key_id of this UpdateSecretRequestBody.

        用于加密保护凭据值的KMS主密钥ID。更新凭据的主密钥后，仅新创建的凭据版本使用更新后的主密钥ID加密，之前的凭据版本依旧使用之前的主密钥ID解密。 

        :param kms_key_id: The kms_key_id of this UpdateSecretRequestBody.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def description(self):
        """Gets the description of this UpdateSecretRequestBody.

        凭据的描述信息。  约束：2048字节。 

        :return: The description of this UpdateSecretRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateSecretRequestBody.

        凭据的描述信息。  约束：2048字节。 

        :param description: The description of this UpdateSecretRequestBody.
        :type: str
        """
        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSecretRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
